@@ -70,14 +70,12 @@ Mixer_ALSA::Mixer_ALSA( Mixer* mixer, int device ) : Mixer_Backend(mixer,  devic
 
 Mixer_ALSA::~Mixer_ALSA()
 {
-//	kDebug() << "Destruct " << this;
    close();
 }
 
 int Mixer_ALSA::identify( snd_mixer_selem_id_t *sid )
 {
    QString name = snd_mixer_selem_id_get_name( sid );
-// kDebug() << name;
    if (name.contains("master"     , Qt::CaseInsensitive)) return MixDevice::VOLUME;
    if (name.contains("master mono", Qt::CaseInsensitive)) return MixDevice::VOLUME;
    if (name.contains("front"      , Qt::CaseInsensitive) &&
@@ -120,7 +118,11 @@ int Mixer_ALSA::open()
 
     snd_mixer_elem_t *elem;
     snd_mixer_selem_id_t *sid;
-    snd_mixer_selem_id_alloca( &sid );
+    bool USE_ALSO_ALLOCA = true; //  TODO remove alloca() when adding "delete sid" in the destructor or close()
+    if (USE_ALSO_ALLOCA)
+    {
+    	snd_mixer_selem_id_alloca( &sid );
+    }
 
     // Determine a card name
     if( m_devnum < -1 || m_devnum > 31 )
@@ -139,7 +141,7 @@ int Mixer_ALSA::open()
         QString msg("No UDI found for '");
         msg += devName;
         msg += "'. Hotplugging not possible";
-        kDebug() << msg;
+        kWarning() << msg;
     }
     // Run a loop over all controls of the card
     unsigned int idx = 0;
@@ -200,7 +202,6 @@ int Mixer_ALSA::open()
         	else
         		finalMixdeviceID = mdID + ".penum"; // playback enum
         }
-        //if ( true || readableName.startsWith("Input Source") ) kDebug() << "Input Source! id=" << finalMixdeviceID << "readableName=" << readableName << ", idx=" << idx;
 
         m_id2numHash[finalMixdeviceID] = idx;
         //kDebug() << "m_id2numHash[mdID] mdID=" << mdID << " idx=" << idx;
@@ -211,52 +212,59 @@ int Mixer_ALSA::open()
 
         MixDevice* mdNew = new MixDevice(_mixer, finalMixdeviceID, readableName, ct );
 
-        if ( volPlay    != 0      ) mdNew->addPlaybackVolume(*volPlay);
-        if ( volCapture != 0      ) mdNew->addCaptureVolume (*volCapture);
-       	if ( !enumList.isEmpty()  ) mdNew->addEnums(enumList);
+        if ( volPlay    != 0      )
+        {
+        	mdNew->addPlaybackVolume(*volPlay);
+            delete volPlay;
+        }
+        if ( volCapture != 0      )
+        {
+        	mdNew->addCaptureVolume (*volCapture);
+            delete volCapture;
+        }
+       	if ( !enumList.isEmpty()  )
+       	{
+       		mdNew->addEnums(enumList);
+            qDeleteAll(enumList); // clear temporary list
+       	}
 
        	shared_ptr<MixDevice> md = mdNew->addToPool();
         m_mixDevices.append( md );
          
-        qDeleteAll(enumList); // clear temporary list
 
         // --- Recommended master ----------------------------------------
         if ( md->playbackVolume().hasVolume() )
         {
           if ( mdID == "Master:0" && masterChosenQuality < 100 ) {
-              kDebug() << "Setting m_recommendedMaster to " << mdID;
+//              kDebug() << "Setting m_recommendedMaster to " << mdID;
               m_recommendedMaster = md;
               masterChosenQuality = 100;
           }
           else if ( mdID == "PCM:0" && masterChosenQuality < 80) {
-              kDebug() << "Setting m_recommendedMaster to " << mdID;
+//              kDebug() << "Setting m_recommendedMaster to " << mdID;
               m_recommendedMaster = md;
               masterChosenQuality = 80;
           }
           else if ( mdID == "Front:0" && masterChosenQuality < 60) {
-              kDebug() << "Setting m_recommendedMaster to " << mdID;
+//              kDebug() << "Setting m_recommendedMaster to " << mdID;
               m_recommendedMaster = md;
               masterChosenQuality = 60;
           }
           else if ( mdID == "DAC:0" && masterChosenQuality < 50) {
-              kDebug() << "Setting m_recommendedMaster to " << mdID;
+//              kDebug() << "Setting m_recommendedMaster to " << mdID;
               m_recommendedMaster = md;
               masterChosenQuality = 50;
           }
           else if ( mdID == "Headphone:0" && masterChosenQuality < 40) {
-              kDebug() << "Setting m_recommendedMaster to " << mdID;
+//              kDebug() << "Setting m_recommendedMaster to " << mdID;
               m_recommendedMaster = md;
               masterChosenQuality = 40;
           }
           else if ( mdID == "Master Mono:0" && masterChosenQuality < 30) {
-              kDebug() << "Setting m_recommendedMaster to " << mdID;
+//              kDebug() << "Setting m_recommendedMaster to " << mdID;
               m_recommendedMaster = md;
               masterChosenQuality = 30;
           }
-
-          //kDebug() << "ALSA create MDW, vol= " << *vol;
-          delete volPlay;
-          delete volCapture;
         }
     } // for all elems
 
@@ -268,7 +276,8 @@ int Mixer_ALSA::open()
     return 0;
 }
 
-
+// warnOnce will make sure we only print the first ALSA device not found
+bool Mixer_ALSA::warnOnce = true;
 /**
  * This opens a ALSA device for further interaction.
  * As this is "slightly" more complicated than calling ::open(),  it is put in a separate method.
@@ -282,7 +291,11 @@ int Mixer_ALSA::openAlsaDevice(const QString& devName)
 
     if ( ( err = snd_ctl_open ( &ctl_handle, devName.toAscii().data(), 0 ) ) < 0 )
     {
-        kDebug() << probeMessage << "not found: snd_ctl_open err=" << snd_strerror(err);
+    	if (Mixer_ALSA::warnOnce)
+    	{
+    		Mixer_ALSA::warnOnce = false;
+    		kDebug() << probeMessage << "not found: snd_ctl_open err=" << snd_strerror(err);
+    	}
         return Mixer::ERR_OPEN;
     }
 
@@ -292,7 +305,11 @@ int Mixer_ALSA::openAlsaDevice(const QString& devName)
     snd_ctl_card_info_alloca(&hw_info);
     if ( ( err = snd_ctl_card_info ( ctl_handle, hw_info ) ) < 0 )
     {
-        kDebug() << probeMessage << "not found: snd_ctl_card_info err=" << snd_strerror(err);
+    	if (Mixer_ALSA::warnOnce)
+    	{
+    		Mixer_ALSA::warnOnce = false;
+    		kDebug() << probeMessage << "not found: snd_ctl_card_info err=" << snd_strerror(err);
+    	}
         //_stateMessage = errorText( Mixer::ERR_READ );
         snd_ctl_close( ctl_handle );
         return Mixer::ERR_READ;
@@ -305,30 +322,47 @@ int Mixer_ALSA::openAlsaDevice(const QString& devName)
     /* open mixer device */
     if ( ( err = snd_mixer_open ( &_handle, 0 ) ) < 0 )
     {
-        kDebug() << probeMessage << "not found: snd_mixer_open err=" << snd_strerror(err);
+    	if (Mixer_ALSA::warnOnce)
+    	{
+    		Mixer_ALSA::warnOnce = false;
+    		kDebug() << probeMessage << "not found: snd_mixer_open err=" << snd_strerror(err);
+    	}
         _handle = 0;
         return Mixer::ERR_OPEN; // if we cannot open the mixer, we have no devices
     }
 
     if ( ( err = snd_mixer_attach ( _handle, devName.toAscii().data() ) ) < 0 )
     {
-        kDebug() << probeMessage << "not found: snd_mixer_attach err=" << snd_strerror(err);
+    	if (Mixer_ALSA::warnOnce)
+    	{
+    		Mixer_ALSA::warnOnce = false;
+    		kDebug() << probeMessage << "not found: snd_mixer_attach err=" << snd_strerror(err);
+    	}
         return Mixer::ERR_OPEN;
     }
 
     if ( ( err = snd_mixer_selem_register ( _handle, NULL, NULL ) ) < 0 )
     {
-        kDebug() << probeMessage << "not found: snd_mixer_selem_register err=" << snd_strerror(err);
+    	if (Mixer_ALSA::warnOnce)
+    	{
+    		Mixer_ALSA::warnOnce = false;
+    		kDebug() << probeMessage << "not found: snd_mixer_selem_register err=" << snd_strerror(err);
+    	}
         return Mixer::ERR_READ;
     }
 
     if ( ( err = snd_mixer_load ( _handle ) ) < 0 )
     {
-        kDebug() << probeMessage << "not found: snd_mixer_load err=" << snd_strerror(err);
+    	if (Mixer_ALSA::warnOnce)
+    	{
+    		Mixer_ALSA::warnOnce = false;
+    		kDebug() << probeMessage << "not found: snd_mixer_load err=" << snd_strerror(err);
+    	}
         close();
         return Mixer::ERR_READ;
     }
 
+    Mixer_ALSA::warnOnce = true;
     kDebug() << probeMessage << "found";
 
     return 0;
@@ -841,7 +875,7 @@ Mixer_ALSA::writeVolumeToHW( const QString& id, shared_ptr<MixDevice> md )
     // --- playback volume
     if ( snd_mixer_selem_has_playback_volume( elem ) )
     {
-    	kDebug() << "phys=" << md->hasPhysicalMuteSwitch() << ", muted=" << md->isMuted();
+//    	kDebug() << "phys=" << md->hasPhysicalMuteSwitch() << ", muted=" << md->isMuted();
     	if ( md->isVirtuallyMuted() )
     	{
     		// Special code path for controls w/o physical mute switch. Doing it in all backends is not perfect,
