@@ -87,9 +87,14 @@ Mixer_Backend* OSS_getMixer( Mixer* mixer, int device )
   return l_mixer;
 }
 
-Mixer_OSS::Mixer_OSS( Mixer* mixer, int device) : Mixer_Backend(mixer, device)
+Mixer_OSS::Mixer_OSS(Mixer* mixer, int device) :
+	Mixer_Backend(mixer, device)
 {
-  if( device == -1 ) m_devnum = 0;
+	if (device == -1)
+	{
+		m_devnum = 0;
+	}
+	m_fd = -1; // point to an invalid FD
 }
 
 Mixer_OSS::~Mixer_OSS()
@@ -237,6 +242,7 @@ QString Mixer_OSS::errorText(int mixer_error)
       break;
     default:
       l_s_errmsg = Mixer_Backend::errorText(mixer_error);
+      break;
     }
   return l_s_errmsg;
 }
@@ -324,6 +330,20 @@ int Mixer_OSS::setRecsrcToOSS( const QString& id, bool on )
 }
 
 
+int Mixer_OSS::id2num(const QString& id)
+{
+	return id.toInt();
+}
+
+/**
+ * Prints out a translated error text for the given error number on stderr
+ */
+void Mixer_OSS::errormsg(int mixer_error)
+{
+	QString l_s_errText;
+	l_s_errText = errorText(mixer_error);
+	kError() << l_s_errText << "\n";
+}
 
 
 int Mixer_OSS::readVolumeFromHW( const QString& id, shared_ptr<MixDevice> md )
