@@ -181,7 +181,7 @@ void Mixer::recreateId()
     primaryKeyOfMixer.replace(' ','_');
     primaryKeyOfMixer.replace('=','_');
     _id = primaryKeyOfMixer;
-//	kDebug() << "Early _id=" << _id;
+	kDebug() << "Early _id=" << _id;
 }
 
 const QString Mixer::dbusPath()
@@ -283,7 +283,8 @@ bool Mixer::openIfValid(int cardId)
             QString noMaster = "---no-master-detected---";
             setLocalMasterMD(noMaster); // no master
         }
-        connect( _mixerBackend, SIGNAL(controlChanged()), SIGNAL(controlChanged()) );
+        // cesken: The following connect() looks mighty strange. I removed it on 2013-12-18
+        //connect( _mixerBackend, SIGNAL(controlChanged()), SIGNAL(controlChanged()) );
         new DBusMixerWrapper(this, dbusPath());
     }
 
@@ -404,12 +405,27 @@ void Mixer::setBalanceInternal(Volume& vol)
  * Returns a name suitable for a human user to read (on a label, ...)
  */
 QString Mixer::readableName()
+{
+	return readableName(false);
+}
+
+/**
+ * Returns a name suitable for a human user to read, possibly with quoted ampersand. The latter is required by
+ * some GUI elements like QRadioButton or when used as a Tab label, as '&' introduces an accelerator there.
+ *
+ * @param ampersandQuoted
+ * @return
+ */
+QString Mixer::readableName(bool ampersandQuoted)
 {
 	QString finalName = _mixerBackend->getName();
-//	QString finalName = mixerName.left(mixerName.length() - 2);
+	if (ampersandQuoted)
+		finalName.replace('&', "&&");
+
 	if ( getCardInstance() > 1)
 		finalName = finalName.append(" %1").arg(getCardInstance());
 
+//	kDebug() << "name=" << _mixerBackend->getName() << "instance=" <<  getCardInstance() << ", finalName" << finalName;
 	return finalName;
 }
 
@@ -584,13 +600,15 @@ shared_ptr<MixDevice> Mixer::find(const QString& mixdeviceID)
 
 shared_ptr<MixDevice> Mixer::getMixdeviceById( const QString& mixdeviceID )
 {
-	shared_ptr<MixDevice> md;
-   int num = _mixerBackend->id2num(mixdeviceID);
-   if ( num!=-1 && num < (int)size() )
-   {
-      md = (*this)[num];
-   }
-   return md;
+	kDebug() << "id=" << mixdeviceID << "md=" << _mixerBackend->m_mixDevices.get(mixdeviceID).get()->id();
+	return _mixerBackend->m_mixDevices.get(mixdeviceID);
+//	shared_ptr<MixDevice> md;
+//   int num = _mixerBackend->id2num(mixdeviceID);
+//   if ( num!=-1 && num < (int)size() )
+//   {
+//      md = (*this)[num];
+//   }
+//   return md;
 }
 
 /**
@@ -618,12 +636,12 @@ void Mixer::commitVolumeChange(shared_ptr<MixDevice> md)
 		// We also cannot rely on a notification from the driver (SocketNotifier), because
 		// nothing has changed, and so there s nothing to notify.
 		_mixerBackend->readSetFromHWforceUpdate();
-		if (GlobalConfig::instance().debugControlManager)
+		if (GlobalConfig::instance().data.debugControlManager)
 			kDebug()
 			<< "committing a control with capture volume, that might announce: " << md->id();
 		_mixerBackend->readSetFromHW();
 	}
-	if (GlobalConfig::instance().debugControlManager)
+	if (GlobalConfig::instance().data.debugControlManager)
 		kDebug()
 		<< "committing announces the change of: " << md->id();
 
