@@ -69,9 +69,10 @@ public:
     void setLabeled( bool value );
     void setTicks( bool ticks );
     void setIcons( bool value );
-    void setIcon( QString filename, QLabel** label );
+//    void setIcon( QString filename, QLabel** label );
     void setIcon( QString filename, QWidget* label );
-    QToolButton* addMediaButton(QString iconName, QLayout* layout);
+    QToolButton* addMediaButton(QString iconName, QLayout* layout, QWidget *parent);
+    void updateMediaButton();
     void setColors( QColor high, QColor low, QColor back );
     void setMutedColors( QColor high, QColor low, QColor back );
     
@@ -96,7 +97,6 @@ public slots:
     void toggleMuted();
     void toggleStereoLinked();
 
-    void setDisabled();
     void setDisabled( bool value );
     void update();
     void showMoveMenu();
@@ -108,6 +108,7 @@ public slots:
 
 signals:
     void toggleMenuBar(bool value);
+    void guiVisibilityChange(MixDeviceWidget* source, bool enable);
 
 private slots:
     void setRecsrc( bool value );
@@ -128,7 +129,6 @@ private slots:
 
 private:
     KShortcut dummyShortcut;
-    void setIcon( QString iconname );
     QPixmap loadIcon( QString filename );
     void createWidgets( bool showMuteLED, bool showCaptureLED );
     void addSliders( QBoxLayout *volLayout, char type, Volume& vol, QList<QAbstractSlider *>& ref_sliders);
@@ -144,7 +144,13 @@ private:
 #endif
 
     QWidget* createLabel(QWidget* parent, QString& label, QBoxLayout *layout, bool);
-
+	QString calculatePlaybackIcon(MediaController::PlayState playState);
+	void guiAddSlidersAndMediacontrols(bool playSliders, bool capSliders, bool mediaControls, QBoxLayout* layout);
+	void guiAddCaptureCheckbox(bool wantsCaptureLED, const Qt::Alignment& alignmentForCapture,
+		QBoxLayout* layoutForCapture);
+	void guiAddMuteButton(bool wantsMuteButton, Qt::Alignment alignment, QBoxLayout* layoutForMuteButton);
+	void guiAddControlIcon(Qt::Alignment alignment, QBoxLayout* layout);
+	void addGlobalShortcut(KAction* action, const QString& label, bool dynamicControl);
 
     bool m_linked;
 
@@ -158,7 +164,8 @@ private:
 	QLabel* m_muteText;
         
 	QLabel *m_label; // is either QLabel or VerticalText
-    
+	QToolButton *mediaButton;
+
 	QCheckBox* m_captureCheckbox;
     QLabel* m_captureText;
 
