@@ -46,9 +46,10 @@ public:
     virtual void constructionFinished();
     virtual void refreshVolumeLevels();
      virtual void showContextMenu();
+     virtual void configurationUpdate();
 
 protected:
-    KMixWindow  *_dock;
+    KMixWindow  *_kmixMainWindow;
 
     void wheelEvent ( QWheelEvent * e );
     virtual void _setMixSet();
